@@ -1,4 +1,4 @@
-;; $Id: prime-engine-prime.el,v 1.9 2004/03/19 17:56:09 komatsu Exp $
+;; $Id: prime-engine-prime.el,v 1.10 2004/03/30 21:10:46 komatsu Exp $
 (defcustom prime-engine-prime-default-use-p nil
   "nil ʳʤȤ߹ prime 󥸥Ѥ")
 (defcustom prime-engine-prime-command "prime"
@@ -202,13 +202,18 @@
 (defun prime-prime-set-lookup-command ()
   ;; FIXME: This version checking routine is not robust.
   ;; FIXME: <komatsu@taiyaki.org> (2004-02-29)
-  (if (and (eq prime-style-display-candidates 'compact)
-	   (string< "0.7.9" (prime-prime-server-version)))
-      (setq prime-engine-command-lookup "lookup_compact"
-	    prime-engine-command-lookup-all "lookup_compact_all")
-    (setq prime-style-display-candidates 'all
-	  prime-engine-command-lookup "lookup"
-	  prime-engine-command-lookup-all "lookup")))
+  (cond ((string< (prime-prime-server-version) "0.7.9")
+	 (setq prime-style-display-candidates 'all
+	       prime-engine-command-lookup "lookup"
+	       prime-engine-command-lookup-all "lookup"))
+
+	((eq prime-style-display-candidates 'compact)
+	 (setq prime-engine-command-lookup "lookup_compact"
+	       prime-engine-command-lookup-all "lookup_compact_all"))
+	((eq prime-style-display-candidates 'all)
+	 (setq prime-engine-command-lookup "lookup"
+	       prime-engine-command-lookup-all "lookup_all"))
+	))
 
 (defun prime-prime-get-env (key)
   (let ((result (prime-prime-send-command (format "get_env\t%s\n" key)))
