@@ -1,4 +1,4 @@
-;; $Id: prime-input-mode.el,v 1.6 2004/02/29 12:38:33 komatsu Exp $
+;; $Id: prime-input-mode.el,v 1.7 2004/03/30 05:44:30 komatsu Exp $
 
 ;; undo $B5!9=$r<+A0$GMQ0U$7$F$$$k$N$G(B, $B$=$N$X$s$rCm0U(B.
 (defun prime-input-mode (&optional arg)
@@ -25,6 +25,8 @@
 	(setq font-lock-fontify-region-function 'prime-fontify-region)
 
 	(and (eq prime-style-display-candidates 'compact)
+	     (not (eq prime-style-display-candidates-compact
+		      'always-number-selection))
 	     (setq prime-enum-mode-ignorep t))
 	)))
 
