@@ -212,7 +212,12 @@
 		(prime-face-find-color prime-cursor-color))
 	       (t
 		prime-default-cursor-color))))
-    (if (not (eq current-color mode-color))
+    ;; FIXME: Use input-method-activate-hook instead of post-command-hook.
+    ;; FIXME: <komatsu@taiyaki.org> (2004-03-19)
+    (if (and (not (eq current-color mode-color))
+	     (or (null current-input-method)
+		 (eq (nth 2 (assoc current-input-method input-method-alist))
+		     'prime-mode)))
 	(set-cursor-color mode-color))
     ))
 
@@ -261,7 +266,8 @@
   (when (sit-for 0.01)
     (prime-erase-cand-list)
     (prime-set-cands pattern)
-    (prime-disp-cand-list))
+    (and (> (length prime-cands) 0)
+	 (prime-disp-cand-list)))
   )
   
 (defun prime-disp-conv (&optional nth)
@@ -284,7 +290,8 @@
   (prime-erase-cand-list)
   (prime-erase-curstr)
   (prime-disp-curstr)
-  (prime-disp-cand-list)
+  (and (> (length prime-cands) 0)
+       (prime-disp-cand-list))
   )  
 
 ;; $B8uJd%j%9%HI=<($r>C$9(B
@@ -356,7 +363,7 @@
       (mell-marker-set 'prime-cand-list-begin (point))
       (prime-disp-cand-list-one)
       )
-     (prime-cand-mode
+     ((or prime-cand-mode); prime-conv-mode)
       (end-of-line)
       ;; marker $B$H$N7s$M9g$$$G$A$g$C$HD>46E*$G$J$$$3$H$K$J$C$F$$$k(B.
       (insert "\n")
@@ -396,7 +403,8 @@
 (defun prime-disp-cand-list-one ()
   (let ((i 0)
 	(offset (+ prime-nth-cand (if prime-conv-mode 1 0))))
-    (while (and (< i 10) (nth (+ i offset) prime-cands))
+    (while (and (< i 10) ;(if prime-conv-mode 10 3))
+		(nth (+ i offset) prime-cands))
       (if (and prime-enum-mode 
 	       (or prime-conv-mode (not prime-enum-mode-ignorep))
 	       (< i (length prime-enum-char-list)))
@@ -407,6 +415,7 @@
       )
     ))
 
+
 (defun prime-disp-cand-list-all ()
   (let ((i 0))
     (while (< i (length prime-cands))
@@ -448,30 +457,14 @@
   (let ((minibuffer-setup-hook (cons 'prime-mode-on minibuffer-setup-hook))
 	(prime-learn-p nil)
 	kana word)
-;    (setq kana (read-string "$BC18lEPO?!VFI$_!W(B: " (prime-get-hiragana pat)))
-    (setq kana (prime-get-hiragana pat))
-    (setq word (read-string (concat "[$BC18lEPO?(B] $B!V(B" kana "$B!W$NJQ49(B: ")))
-    (prime-server-dict-register-word word kana)
+    (setq pron (prime-input-get-label pat))
+    (setq word (read-string (concat "[$BC18lEPO?(B] $B!V(B" pron "$B!W$NJQ49(B: ")))
+    (prime-server-dict-register-word word pron)
     (prime-fix-without-learn word)
     (prime-fund-mode t)
     )
   )
 
-;(defun prime-register-word (&optional pat)
-;  (interactive)
-;  (setq pat (or pat prime-pat))
-;  (prime-server-dict-register-word word pat)
-;  (prime-fix-without-learn word)
-;  (prime-fund-mode t)
-;  )
-
-;(defun prime-register-read-pattern-romaji (&optional pat)
-;  (let ((prime-learn-p nil))
-;    (read-from-minibuffer "$BC18lEPO?!VFI$_(B($B%m!<%^;z(B)$B!W(B: " pat)
-;    ))
-
-;(defun prime-register-read-pattern (&optional pat)
-
 (defun prime-get-nth (&optional word pattern)
   (if (not word)
       prime-nth-cand
